@@ -292,6 +292,7 @@ class spectrum:
 				return 0 # "running."
 			except OSError, err:
 			# except OSError as err: #python3
+				import errno
 				if err.errno == errno.ESRCH:
 					return 1 # "not running but pid file exists."
 				else:
@@ -683,11 +684,32 @@ class spectrum:
 		if not os.path.exists( log_file ):
 			raise RuntimeError( "Error: %s: Logfile does not exist."%(log_file) )
 
+
+#		for line in open(log_file).readlines()[:50]:
+#			output_file.write( line )
+		f = open( log_file )
+		f.seek( 0, 2 ) # seek to end
+		total_size = f.tell() # get total size
+		size = 50
+		block= -1
+		while size > 0 and total_size + block * 1024 > 0:
+			f.seek( block * 1024, 2 )
+			data = f.read( 1024 )
+			linesFound = data.count('\n')
+			size -= linesFound
+			block -= 1
+
+		if -block*1024 < total_size:
+			f.seek( block*1024, 2 )
+			f.readline() # find newline
+		else:
+			f.seek( 0 )
+		lastBlocks = f.readlines()[-50:]
+
+		# write lines to output file
 		output_path = self._get_output_file( output_dir, self.get_jid(), 'log' )
 		output_file = open( output_path, 'w' )
-
-		for line in open(log_file).readlines()[:50]:
-			output_file.write( line )
+		output_file.writelines( lastBlocks )
 
 		return os.path.normpath( output_path )
 
